<p align="center">
  <img src="docs/sphinx/images/logo_4.svg" width="600">
</p>
The Robust design optimization of renewable Hydrogen and dErIved energy cArrier systems (RHEIA) framework provides 
multi-objective optimization (deterministic and stochastic) and uncertainty quantification algorithms. 
These algorithms can be applied on hydrogen-based energy systems, which are included in RHEIA.
In addition, RHEIA allows to connect your own models to the algorithms as well.


Documentation
=============

The documentation is available at [readthedocs](https://rheia.readthedocs.io/en/latest/).


Installation
============

RHEIA can be installed using ``pip``.
More information is available at the [Installation page](https://rheia.readthedocs.io/en/latest/installation.html) of the documentation.


License
=======

[MIT license](https://github.com/rheia-framework/RHEIA/blob/main/LICENSE)

Support
=======

Contact us for questions and feedback:

rheia.framework@gmail.com